summaryrefslogtreecommitdiff
path: root/src/theory/interrupted.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/interrupted.h')
-rw-r--r--src/theory/interrupted.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/theory/interrupted.h b/src/theory/interrupted.h
index 76dc36e79..75c8f93a5 100644
--- a/src/theory/interrupted.h
+++ b/src/theory/interrupted.h
@@ -15,7 +15,7 @@
** An exception signaling that a Theory should immediately stop
** performing processing and relinquish control to its caller (e.g.,
** in a parallel environment). A Theory might be interrupted if it
** calls into its CVC4::theory::OutputChannel, and it should only
** catch this exception to perform emergency repair of any invariants
** it must re-establish. Further, if this exception is caught by a
** Theory, the Theory should rethrow the same exception (via "throw;"
@@ -31,13 +31,14 @@
#include "base/exception.h"
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
-class Interrupted : public CVC4::Exception {
-};/* class Interrupted */
+class Interrupted : public CVC5::Exception
+{
+}; /* class Interrupted */
-}/* CVC4::theory namespace */
-}/* CVC4 namespace */
+} // namespace theory
+} // namespace CVC5
#endif /* CVC4__THEORY__INTERRUPTED_H */
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -15,7 +15,7 @@
** performing processing and relinquish control to its caller (e.g.,
** in a parallel environment). A Theory might be interrupted if it
- ** calls into its CVC4::theory::OutputChannel, and it should only
+ ** calls into its CVC5::theory::OutputChannel, and it should only
** catch this exception to perform emergency repair of any invariants
** it must re-establish. Further, if this exception is caught by a